@@ -1,10 +1,19 @@
 import click
 
-from strava.commands import login, logout, get_activities, get_activity, get_profile, get_stats, set_config, post_upload
+from strava.commands import (
+    login,
+    logout,
+    get_activities,
+    get_activity,
+    get_profile,
+    get_stats,
+    set_config,
+    post_upload,
+)
 
 
 @click.group()
-@click.version_option()
+@click.version_option(package_name="strava-cli")
 def cli():
     pass
 
@@ -18,5 +27,5 @@ cli.add_command(get_stats)
 cli.add_command(set_config)
 cli.add_command(post_upload)
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli()
