@@ -6,3 +6,14 @@ from .login import login
 from .logout import logout
 from .profile import get_profile
 from .stats import get_stats
+
+__all__ = [
+    "get_activities",
+    "get_activity",
+    "post_upload",
+    "set_config",
+    "login",
+    "logout",
+    "get_profile",
+    "get_stats",
+]
