@@ -3,13 +3,10 @@ import click
 from strava import api
 from strava.decorators import output_option, login_required, format_result, OutputType
 
-_PROFILE_COLUMNS = (
-    'key',
-    'value'
-)
+_PROFILE_COLUMNS = ("key", "value")
 
 
-@click.command('profile')
+@click.command("profile")
 @output_option()
 @login_required
 @format_result(table_columns=_PROFILE_COLUMNS)
@@ -23,10 +20,10 @@ def _as_table(athlete):
         return f'{athlete.get("firstname")} {athlete.get("lastname")}'
 
     formatted_athlete = {
-        'id': athlete.get('id'),
-        'username': athlete.get('username'),
-        'name': format_name(),
-        'email': athlete.get('email')
+        "id": athlete.get("id"),
+        "username": athlete.get("username"),
+        "name": format_name(),
+        "email": athlete.get("email"),
     }
 
-    return [{'key': k, 'value': v} for k, v in formatted_athlete.items()]
+    return [{"key": k, "value": v} for k, v in formatted_athlete.items()]
