@@ -3,7 +3,7 @@ import os
 
 
 def _get_local_store_dir():
-    return os.path.expanduser(os.path.join('~', '.strava-cli'))
+    return os.path.expanduser(os.path.join("~", ".strava-cli"))
 
 
 def _get_fullpath(filename):
@@ -13,15 +13,16 @@ def _get_fullpath(filename):
 def save(filename, data):
     fullpath = _get_fullpath(filename)
     os.makedirs(os.path.dirname(fullpath), exist_ok=True)
-    with os.fdopen(os.open(fullpath, os.O_RDWR | os.O_CREAT | os.O_TRUNC, 0o600),
-                   'w+') as file:
+    with os.fdopen(
+        os.open(fullpath, os.O_RDWR | os.O_CREAT | os.O_TRUNC, 0o600), "w+"
+    ) as file:
         json.dump(data, file)
 
 
 def load(filename):
     fullpath = _get_fullpath(filename)
     if os.path.isfile(fullpath):
-        with open(fullpath, 'rb') as file:
+        with open(fullpath, "rb") as file:
             return json.load(file)
     else:
         return None
